@@ -22,7 +22,13 @@
 
 import datetime
 import os.path
-import gnomeapplet, gtk
+
+import pygtk
+pygtk.require("2.0")
+import gtk
+gtk.gdk.threads_init()
+
+import gnomeapplet
 import gobject
 import dbus
 import dbus.service
@@ -36,6 +42,12 @@ from hamster.stuff import *
 from hamster.KeyBinder import *
 from hamster.hamsterdbus import HAMSTER_URI, HamsterDbusController 
 
+# controllers for other windows
+from hamster.add_custom_fact import CustomFactController
+from hamster.stats import StatsViewer
+from hamster.about import show_about
+from hamster.preferences import PreferencesEditor
+
 import idle
 
 try:
@@ -55,10 +67,12 @@ class Notifier(object):
         if not pynotify.is_initted():
             pynotify.init(app_name)
 
-    def msg(self, body, switch_cb, stop_cb):
+    def msg(self, body, edit_cb, switch_cb):
         self._notify = pynotify.Notification(self.summary, body, self._icon, self._attach)
-        self._notify.add_action("refresh", _("Switch Task"), switch_cb)
-        self._notify.add_action("no", _("Stop Tracking"), stop_cb)
+        #translators: this is edit activity action in the notifier bubble
+        self._notify.add_action("edit", _("Edit"), edit_cb)
+        #translators: this is switch activity action in the notifier bubble
+        self._notify.add_action("switch", _("Switch"), switch_cb)
         self._notify.show()
 
 
@@ -359,7 +373,6 @@ class HamsterApplet(object):
             (model, iter) = selection.get_selected()
             fact_id = model[iter][0]
                 
-            from hamster.add_custom_fact import CustomFactController
             custom_fact = CustomFactController(None, fact_id)
             custom_fact.show()
             return True
@@ -405,7 +418,6 @@ class HamsterApplet(object):
             label = "%s %s" % (self.last_activity['name'], format_duration(duration))
             self.button.set_text(self.last_activity['name'], format_duration(duration))
             
-            self.glade.get_widget('current_activity').set_text(self.last_activity['name'])
             self.glade.get_widget('stop_tracking').set_sensitive(1);
         else:
             label = "%s" % _(u"No activity")
@@ -422,15 +434,16 @@ class HamsterApplet(object):
                  
         if duration and duration % self.notify_interval == 0:
             # activity reminder
-            msg = _(u"Are you still working on <b>%s</b>?") % self.last_activity['name']
-            self.notify.msg(msg, self.switch_cb, self.stop_cb)
+            msg = _(u"Working on <b>%s</b>") % self.last_activity['name']
+            self.notify.msg(msg, self.edit_cb, self.switch_cb)
+
+    def edit_cb(self, n, action):
+        custom_fact = CustomFactController(None, self.last_activity['id'])
+        custom_fact.show()
 
     def switch_cb(self, n, action):
         self.__show_toggle(None, not self.button.get_active())	
 
-    def stop_cb(self, n, action):
-        self.on_stop_tracking(None)
-
 
     def load_day(self):
         """sets up today's tree and fills it with records
@@ -520,7 +533,9 @@ class HamsterApplet(object):
 
         self.load_day() # reload day each time before showing to avoid outdated last activity
         self.update_label() #update also label, otherwise we can get 1 minute difference in durations (due to timers refreshed once a minute)
-        
+
+        if self.last_activity: #reset value of current_activity input, maybe we have some leftovers there
+            self.glade.get_widget('current_activity').set_text(self.last_activity['name'])        
 
         label_geom = self.button.get_allocation()
         window_geom = self.window.get_allocation()
@@ -615,7 +630,6 @@ class HamsterApplet(object):
         dispatcher.dispatch('panel_visible', False)
 
     def on_overview(self, menu_item):
-        from hamster.stats import StatsViewer
         dispatcher.dispatch('panel_visible', False)
         stats_viewer = StatsViewer()
         stats_viewer.show()
@@ -624,7 +638,6 @@ class HamsterApplet(object):
         return self.on_overview(menu_item)
 
     def on_custom_fact(self, menu_item):
-        from hamster.add_custom_fact import CustomFactController
         custom_fact = CustomFactController()
         custom_fact.show()
 
@@ -632,12 +645,9 @@ class HamsterApplet(object):
         if self.applet.about:
             self.applet.about.present()
         else:
-            from hamster.about import show_about
             show_about(self.applet)
 
     def show_preferences(self, menu_item, verb):
-        from hamster.preferences import PreferencesEditor
-
         dispatcher.dispatch('panel_visible', False)
         
         if self.preferences_editor and self.preferences_editor.window:
